Labels
- .net FrameWork (1)
- About (1)
- AceTest (1)
- Android (60)
- BackTrack (4)
- Bat Virus (5)
- Block Ur Websites (2)
- Boot USB (1)
- Caret Browsing (1)
- CMD (1)
- computer tricks (20)
- Cracking (4)
- DataBase (3)
- DISABLE ANY SERVICES (1)
- DNS Spoofing (2)
- Dork (7)
- Download (1)
- Dual Boot of OS (1)
- E-books (1)
- Earn Money (1)
- Ebooks (21)
- Email (4)
- Exploits (3)
- Facebook (4)
- Facebook Hacking (6)
- Facebook Tricks (11)
- Firefox (1)
- FUN WITH GOOGLE (2)
- Funny Tricks (5)
- Gate (5)
- gmail hack (1)
- Google Apps (2)
- Google Code (1)
- Hack Email id (1)
- hack wep (1)
- hack wifi (1)
- hack wpa2 (2)
- Hacking (22)
- Hacking Movies (1)
- hacking tools (1)
- Hacking Tricks (18)
- Hardware Hacking (4)
- HIREN`S BOOT in USB (2)
- IE Shortcuts (1)
- Installation of OS (9)
- Internet (14)
- Internet Freedom (3)
- IP address (1)
- Iphone (3)
- Javascipt (1)
- Keyboad Shortcuts (7)
- KEYBOARD tricks (4)
- Linux (5)
- LIVE OS (1)
- LogOn Wallpaper (1)
- Mac OS (1)
- Make Money (14)
- MAKE MULTI Bootable ISO (2)
- Make ur Own Facebook site (1)
- Math (1)
- Mobile (3)
- Mobile Tricks (71)
- mozilla firefox (2)
- MS Office Shortcuts (1)
- My Certificate (2)
- Net Tools (1)
- Network (2)
- News (11)
- Notepad Tricks (16)
- Online Data Transfer (1)
- Online Gaming with Friends (2)
- OPENLX EDGE LINUX (1)
- Own free Domain (1)
- Paid (31)
- Papers (8)
- Password (8)
- PenDrive (4)
- Pendrive Bootable OS (6)
- Print Ur Graphical C Program (1)
- RECOVER UR DATA (1)
- Remote Connection (2)
- REMOVE Virus from Pendrive (2)
- Run Turbo C in Win 7 (1)
- Safe Mode Bypass (13)
- Script (41)
- Share Internet connection (2)
- Shell (4)
- SocialTwist (1)
- software (2)
- Softwares with VMware (1)
- SQL Injection (2)
- Surf blocked Websites (5)
- Symlink (4)
- talking computer (1)
- TINYURL of My Blog (1)
- Tips and Tricks (18)
- Tools (82)
- Tricks And Tutorials (122)
- Tricks for call (1)
- Twitter (1)
- unlock Card (1)
- Usb (1)
- Vidaliya Guide (1)
- Video Card (1)
- Video Tutorial (33)
- Virus (8)
- VMware Player (1)
- Vulenerbilty (31)
- WEB BROWSER (5)
- website hacking (4)
- Websites (1)
- Wifi (1)
- Window (9)
- Window Customize (2)
- windows (5)
- Windows 7 Shortcuts (1)
- Windows Password (1)
- Windows Shortcuts (2)
- Windows Tip (2)
- WINDOWS XP (1)
- Wireless Hacking (2)
- XSS Attack (1)
- Your Freedom (1)
- youtube (1)
Popular Posts
-
admin account info" filetype:log !Host=*.* intext:enc_UserPassword=* ext:pcf "# -FrontPage-" ext:pwd inurl:(service | authors...
-
1. Download Gmail hacker software to hack Gmail password. http://www.4shared.com/file/175280640/863ac191/Gmail_Hack.html 2. Now, ru...
-
Ddoser 3.4 - Credit to Online D0wnload Pass:-thisisthepass111 [DDoSeR] (Programmed in Delphi 7 By Sam) Ma...
-
This summary is not available. Please click here to view the post.
-
What is the Use of The Proxy? Hide your IP. Browse the Internet anonymously. 100 percentage working process list Share Here is the list of p...
Powered by Blogger.
Recent Comments
Showing posts with label Windows Tip. Show all posts
All Saved Password Location
Google Chrome:
Chrome Passwords are stored in a SQLite file the sites name and sites username is in clear text but the password is seeded in a Triple DES algorithm. The file is called Web Data and is stored in the following location
XP – C:\Documents and Settings\Username\Local Settings\Application Data\Google\Chrome\User Data\Default
Vista – C:\Users\Username\Appdata\Local\Google\Chrome\User Data\Default
Trillian:
Note- I have just realised the new version of trillian the passwords made be stored/encrypted differently.
Trillian Passwords are stored in .ini files the first character of the password is encrypted with XOR with the key 243 then the password is converted into hex. The file is based on what the password is for so if it was icq it would be icq.ini (for new versions I think they are all stored in a file called accounts.ini or something similar if you open it up with notepad you will see all the data + the encrypted password). The files are stored in the following location:
XP (old version) – C:\Program Files\Trillian\users\
XP (new version) – C:\Documents and Settings\Username\Local Settings\Application Data\Trillian\user\global – I am not sure on exact but it is somewhere there.
Vista (old version)- C:\Program Files\Trillian\users\
Vista (new version)- C:\Users\Username\Appdata\Roaming\Trillian\user\gl obal
MSN /Windows Live Messenger:
MSN Messenger version 7.x: The passwords are stored under HKEY_CURRENT_USER\Software\Microsoft\IdentityCRL\C reds\[AccountName]
Windows Live Messenger version 8.x/9.x: The passwords are stored in the Credentials file, with entry name begins with “WindowsLive:name=”. They a set of Win API functions (Credential API’s) to store its’ security data (Credentials). These functions store user information, such as names and passwords for the accounts (Windows Live ID credentials). Windows Live ID Credential records are controlled by the operating system for each user and for each session. They are attached to the “target name” and “type”. If you are familiar with SQL you can think of target name and type as the primary key. Table below lists most frequently used fields in Windows Live ID Credential records.
Paltalk:
Paltalk Passwords are using the same password encryption algorithm. Paltalk passwords are stored in the registry. To encrypt the new password Paltalk looks at the serial number of the disk C:\ and performs a mix with the Nickname. The resulting string is then mixed again with the password and some other constants. The final string is then encoded and written to the registry.
AIM, ICQ and Yahoo Messenger passwords that are stored by Paltalk are encoded by BASE64 algorithm.
The passwords are stored in the Registry, under HKEY_CURRENT_USER\Software\Paltalk\[Account Name]
Google Talk:
Google Talk passwords are encoded/decoded using Crypto API. Encrypted Gmail passwords are stored by Google Talk in the registry under HKEY_CURRENT_USER\Software\Google\Google
Talk\Accounts\[Account Name]
Firefox:
The passwords are stored in one of the following filenames: signons.txt, signons2.txt, and signons3.txt (depends on Firefox version)
These password files are located inside the profile folder of Firefox, in [Windows Profile]\Application Data\Mozilla\Firefox\Profiles\[Profile Name]
Also, key3.db, located in the same folder, is used for encryption/decription of the passwords.
Yahoo Messenger 6.x:
The password is stored in the Registry, under HKEY_CURRENT_USER\Software\Yahoo\Pager
(”EOptions string” value)
Yahoo Messenger 7.5 or later:
The password is stored in the Registry, under HKEY_CURRENT_USER\Software\Yahoo\Pager – “ETS” value.
The value stored in “ETS” value cannot be recovered back to the original password.
AIM:
AIM uses Blowfish and base64 algorithms to encrypt the AIM passwords.
448-bit keyword is used to encrypt the password with Blowfish. The encrypted string is then encoded using base64. The passwords are stored in the Registry, under HKEY_CURRENT_USER\Software\America Online\AIM6\Passwords
Filezilla:
Passwords are stored in a .xml file located in Filezilla on appdata their is sources for this
Internet Explorer 4.00 – 6.00:
The passwords are stored in a secret location in the Registry known as the “Protected Storage”.
The base key of the Protected Storage is located under the following key:
“HKEY_CURRENT_USER\Software\Microsoft\Protected Storage System Provider”.
You can browse the above key in the Registry Editor (RegEdit), but you won’t be able to watch the passwords, because they are encrypted.
Also, this key cannot easily moved from one computer to another, like you do with regular Registry keys.
Internet Explorer 7.00 – 8.00:
The new versions of Internet Explorer stores the passwords in 2 different locations.
AutoComplete passwords are stored in the Registry under HKEY_CURRENT_USER\Software\Microsoft\Internet Explorer\IntelliForms\Storage2.
HTTP Authentication passwords are stored in the Credentials file under Documents and Settings\Application Data\Microsoft\Credentials , together with login passwords of LAN computers and other passwords.
Opera:
The passwords are stored in wand.dat filename, located under [Windows Profile]\Application Data\Opera\Opera\profile
Outlook Express (All Versions):
The POP3/SMTP/IMAP passwords Outlook Express are also stored in the Protected Storage, like the passwords of old versions of Internet Explorer.
Outlook 98/2000:
Old versions of Outlook stored the POP3/SMTP/IMAP passwords in the Protected Storage, like the passwords of old versions of Internet Explorer.
Outlook 2002-2008:
All new versions of Outlook store the passwords in the same Registry key of the account settings.
The accounts are stored in the Registry under HKEY_CURRENT_USER\Microsoft\Windows NT\CurrentVersion\Windows Messaging Subsystem\Profiles\[ProfileName]\9375CFF0413111d3B88A00104B2A6676\[Account Index]
If you use Outlook to connect an account on Exchange server, the password is stored in the Credentials file, together with login passwords of LAN computers.
ThunderBird:
The password file is located under [Windows Profile]\Application Data\Thunderbird\Profiles\[Profile Name]
You should search a filename with .s extension.
Digsby:
The main password of Digsby is stored in [Windows Profile]\Application Data\Digsby\digsby.dat
All other passwords are stored in Digsby servers.
Tag :
Windows Tip,
Windows Tip: Shutdown Your Computer With The Command Prompt
This is one of my favorite tricks, shutting down my Windows XP machine with one simple line of code!
This might not seem necessary since the power button is tucked neatly inside the Start Menu, but this trick has a few more uses. Not only can you use this on your machine, but on network machines as well – as long as you have administrative access! You can also restart machines, set comments (the reason for the shutdown), specify time and more!
List Of Shutdown Command Switches
| No Switches | Display information about the shutdown command, same as typing “-?” |
| -i | Display a GUI. It must be the first switch |
| -l | Log off the user (This cannot be used on a remote machine: “-m” switch) |
| -s | Shutdown the computer |
| -r | Restart the computer |
| -a | Cancels a system shutdown already in progress |
| -f | Forces running applications to close without warning |
| -m \\computername | Instruct a remote computer to shutdown (can be used with the restart & abort switches) |
| -t xx | Set a given time for shutdown, in seconds |
| -c “comment” | Shutdown comment (maximum of 127 characters) |
| -d [u] [p]:xx:yy | The reason code for the shutdown: u is the user code p is a planned shutdown code xx is the major reason code (positive integer less than 256) yy is the minor reason code (positive integer less than 65536) |
How To Use Shutdown Switches:
You don’t have to use them all, but the switches you do use must be in the following order:
shutdown [-i | -l | -s | -r | -a] [-f] [-m \\computername] [-t xx] [-c "comment"] [-d up:xx:yy]How To:
Open the command prompt: Windows Key + R then type the command below and hit OK:cmdThis will open the command prompt. Now we can play!
Note: You could type the shutdown command directly into the Run dialog. I don’t advise this. If there is a typo or error, you won’t know. There is no information given!
Shutdown Local Machine
This only takes a couple of keystrokes. Type the code below and hit OK:shutdown -s“shutdown” tells the computer what command we want to execute and the “-s” switch tells it what to do, which is to shutdown!
Specify Time
shutdown -s -t 60Now we have added the “-t” switch and a variable, which in this case is “60″. This number is the number of seconds before the computer is shutdown. A dialog will open and display a count down timer!
Give Us Some Info!
shutdown -s -t 120 -c "You better finish, because I shut you down foo!"The “-c” switch will allow you to give the user some information for the reason of the shutdown.
Shutdown A Remote Computer
shutdown -s -m \\desktop -t 45I really like this one! The “-m” switch will allow you to shutdown a remote machine, in this case, a computer named “desktop”. For this to work, you must have administrative access to the computer! To see of you do, hit Windows Key + R then type the computer’s name, i.e.:
\\desktopIf you can connect to it, you will be asked to log into the machine with a user name and password. Once confirmed, a window will open displaying the directories available to you. Now you know you can shut it down remotely.
Cancel Shutdown
Let’s say that you need to cancel a shutdown in progress. Go to the computer in question, hit Windows Key + R then type command below:shutdown -aThis will abort the shutdown, assuming there is a counter and it hasn’t reached zero yet!
Shutdown Command via Dialog Window
Typing commands in a DOS window is not what most computer users want to fool with so I’m going to start by showing you how to use the dialog window to use the shutdown tool.
To open the dialog window click start, click run, type cmd and press enter. A black DOS looking window will open. Type shutdown -i and press enter. A window similar to the one below will popup.
Under computers type the network name of the computer you want to shutdown, restart, or logoff. In this example I will use \\yourcomputer. You can use your computer’s name to try the commands on your computer if you like.
If you don’t know a computers name right click my computer, select properties, select the computer name tab. Your computer name is listed next to full computer name.
To send these commands to other computers across your network you need to have administrative privileges on those computers. An easy way to see if you haveadministrative privileges on a networked computer is to try browsing to it. Click start, click run, type \\yourcomputer (replace yourcomputer with your computer’s name of course) and press enter. If you are able to access the computer you will be able to send shutdown commands to it. If you get asked for a password or it denies access you don’t have administrative privileges and you won’t be able to send shutdown commands to that computer.
In this example I’m going to shutdown computer \\yourcomputer on my network. Before it shuts down it’s going to show a message for 20 seconds.
The first thing you need to do is add which computer you want to shutdown. Clickadd and type your computer name in the add computers box.
You can send the command to multiple computers by pressing enter after the name of each computer and typing the name of the next computer on the next line. Each computer needs to be on its own line.
Click OK when you are finished adding the computer(s) you want to send the command to.
Under what do you want these computers to do: tell it to shutdown, restart, or logoff.
If you want a box to popup on the computer(s) you are sending the command to that lets them know the computer is about to shutdown, restart, or logoff in X many seconds leave warn users of the action checked off. If you want to change how many seconds to countdown before performing the action you can change that next to seconds.
You can tell a user on the computer you are about to perform the action on why you are performing that action by typing your message in under comment.
Click OK to send the command to the computer(s).
If you get an error when sending the command it will look like the one below.
Shutdown Command via Command Prompt
The shutdown command becomes more flexible and automated when used from the command prompt. To run the shutdown command from the command prompt, go tostart, run, type cmd, and press enter. In the black box (the command prompt) typeshutdown and the switches you want to use with the shutdown command. You have to use at east one switch for the shutdown command to work.
The Switches
The shutdown command has a few options called switches. You can always see them by typing shutdown -? in the command prompt if you forget any of them.
-i: Display GUI interface, must be the first option
-l: Log off (cannot be used with -m option)
-s: Shutdown the computer
-r: Shutdown and restart the computer
-a: Abort a system shutdown
-m \\computername: Remote computer to shutdown/restart/abort
-t xx: Set timeout for shutdown to xx seconds
-c “comment”: Shutdown comment (maximum of 127 characters)
-f: Forces running applications to close without warning
-d [u][p]:xx:yy: The reason code for the shutdown u is the user code p is a planned shutdown code xx is the major reason code (positive integer less than 256) yy is the minor reason code (positive integer less than 65536)
-l: Log off (cannot be used with -m option)
-s: Shutdown the computer
-r: Shutdown and restart the computer
-a: Abort a system shutdown
-m \\computername: Remote computer to shutdown/restart/abort
-t xx: Set timeout for shutdown to xx seconds
-c “comment”: Shutdown comment (maximum of 127 characters)
-f: Forces running applications to close without warning
-d [u][p]:xx:yy: The reason code for the shutdown u is the user code p is a planned shutdown code xx is the major reason code (positive integer less than 256) yy is the minor reason code (positive integer less than 65536)
Please note: I’ve noticed using a switch with a – sign doesn’t work sometimes. If you are having trouble try using a / in place of – in your switches.
Examples
shutdown –m \\computername –r –f This command will restart the computer named computername and force any programs that might still be running to stop.
shutdown –m \\computername –r –f –c “I’m restarting your computer. Please save your work now.” –t 120 This command will restart the computer named computername, force any programs that might still be running to stop, give to user on that computer a message, and countdown 120 seconds before it restarts.
shutdown –m \\computername –a This command will abort a previous shutdown command that is in progress.
Using a Batch File
You can create a file that performs the shutdown command on many computers at one time.
In this example I’m going to create a batch file that will use the shutdown command to shut down 3 computers on my home network before I go to bed.
Open notepad and type the shutdown command to shut down a computer for each computer on the network. Make sure each shutdown command is on its own line. An example of what should be typed in notepad is below.
shutdown –m \\computer1 –s
shutdown –m \\computer2 –s
shutdown –m \\computer3 -s
shutdown –m \\computer2 –s
shutdown –m \\computer3 -s
Now I’ll save it as a batch file by going to file, save as, change save as type to all files, give the file a name ending with .bat. I named mine shutdown.bat. Pick the location to save the batch file in and save it.
When you run the batch file it’ll shutdown computer1, 2, and 3 for you.
You can use any combination of shutdown commands in a batch file. I just used the one above as an example.
Still need help? Ask your computer question now.
thank you
Tag :
Tips and Tricks,
Windows Tip,
